@@ -50,9 +50,9 @@ sub _command_list {
   my %map = (
     help    => 'help\s+-',
     install => 'install\s+- how to install',
-    simple  => 'simple\s+- alternative text for simple command',
-    args    => 'with_args\s+- args test',
-    options => 'with_options\s+- option test',
+    simple  => 'simple\s+- alternative text for simple command \[disabled: compile error\]',
+    args    => 'with_args\s+- args test \[disabled: compile error\]',
+    options => 'with_options\s+- option test \[disabled: compile error\]',
   );
 
   foreach my $key ( keys %map ) {
