@@ -10,7 +10,7 @@ sub simple_dispatch : Test {
 
   my $ret = $class->dispatch(qw( simple ));
 
-  ok $ret eq 'simple', $class->message('dispatch succeeded');
+  ok $ret eq 'simple', $class->message("dispatch succeeded: $ret");
 }
 
 sub simple_with_args : Test {
@@ -18,7 +18,7 @@ sub simple_with_args : Test {
 
   my $ret = $class->dispatch(qw( with_args one two three ));
 
-  ok $ret eq 'onetwothree', $class->message('dispatch succeeded');
+  ok $ret eq 'onetwothree', $class->message("dispatch succeeded: $ret");
 }
 
 sub simple_with_options : Test {
@@ -26,7 +26,7 @@ sub simple_with_options : Test {
 
   my $ret = $class->dispatch(qw( WithOptions --hello --target=world ));
 
-  ok $ret eq 'hello world', $class->message('dispatch succeeded');
+  ok $ret eq 'hello world', $class->message("dispatch succeeded: $ret");
 }
 
 sub dispatch {
